From: Waiman Long <longman@redhat.com>
To: Peter Zijlstra <peterz@infradead.org>
Cc: Ingo Molnar <mingo@redhat.com>,
Andrew Morton <akpm@linux-foundation.org>,
Mathieu Desnoyers <mathieu.desnoyers@efficios.com>,
Michel Lespinasse <walken@google.com>,
linux-kernel@vger.kernel.org
Subject: Re: [PATCH] sched, mm: Optimize current_gfp_context()
Date: Thu, 18 Jun 2020 16:59:18 -0400 [thread overview]
Message-ID: <6333186c-224a-fb84-7304-ca7c6c903c13@redhat.com> (raw)
In-Reply-To: <20200618160726.GL576905@hirez.programming.kicks-ass.net>
On 6/18/20 12:07 PM, Peter Zijlstra wrote:
> On Thu, Jun 18, 2020 at 11:58:47AM -0400, Waiman Long wrote:
>> The current_gfp_context() converts a number of PF_MEMALLOC_* per-process
>> flags into the corresponding GFP_* flags for memory allocation. In
>> that function, current->flags is accessed 3 times. That may lead to
>> duplicated access of the same memory location.
>>
>> This is not usually a problem with minimal debug config options on as the
>> compiler can optimize away the duplicated memory accesses. With most
>> of the debug config options on, however, that may not be the case.
>> For example, the x86-64 object size of the __need_fs_reclaim() in a
>> debug kernel that calls current_gfp_context() was 309 bytes. With this
>> patch applied, the object size is reduced to 202 bytes. This is a saving
>> of 107 bytes and will probably be slightly faster too.
>>
>> Signed-off-by: Waiman Long <longman@redhat.com>
>> ---
>> include/linux/sched/mm.h | 10 ++++++----
>> 1 file changed, 6 insertions(+), 4 deletions(-)
>>
>> diff --git a/include/linux/sched/mm.h b/include/linux/sched/mm.h
>> index 480a4d1b7dd8..09e01909d192 100644
>> --- a/include/linux/sched/mm.h
>> +++ b/include/linux/sched/mm.h
>> @@ -181,18 +181,20 @@ static inline bool in_vfork(struct task_struct *tsk)
>> */
>> static inline gfp_t current_gfp_context(gfp_t flags)
>> {
>> - if (unlikely(current->flags &
>> + unsigned int pflags = current->flags;
> Per the above, I would've expected a READ_ONCE() there, otherwise the
> compiler can still re-load.
>
Right. Will do that.
Thanks,
Longman
prev parent reply other threads:[~2020-06-18 20:59 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2020-06-18 15:58 Waiman Long
2020-06-18 16:07 ` Peter Zijlstra
2020-06-18 20:59 ` Waiman Long [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=6333186c-224a-fb84-7304-ca7c6c903c13@redhat.com \
--to=longman@redhat.com \
--cc=akpm@linux-foundation.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mathieu.desnoyers@efficios.com \
--cc=mingo@redhat.com \
--cc=peterz@infradead.org \
--cc=walken@google.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®